#ifndef COMMAND_H
#define COMMAND_H

#include <stdint.h>

#include "error.h"

/*
 * The two modes the program can be in.
 */
typedef enum {
	NORMAL_MODE,
	CONFIG_MODE
} mode_t;

/*
 * Returns the length of data (including the command) to be
 * expected for a given command code.
 *
 * set_mode must be called before this.
 */
int command_length(char command_code);

/*
 * Sets the operating mode to normal or config mode, therefore deciding how
 * the commands are interpreted.
 *
 * The 'mode' argument must be NORMAL_MODE or CONFIG_MODE.
 */
void set_mode(mode_t mode);

/*
 * Returns the operating mode.
 */
mode_t get_mode();

/*
 * Runs the command pointed to by 'command'. How the command is interpreted
 * depends on which mode the LED board is in.
 * Make sure that command has the right length (as indicated by command_length)!
 *
 * Returns an error/success code.
 */
error_t run_command(uint8_t *command);

#endif
