#! /usr/bin/python

import sys

FILE_START = \
"""/*
 * This file contains the table that is used for gamma-correcting the incoming
 * values for display. The LED brightness is given as a table of 16-bit integers
 * indexed by 8-bit integers (being the brightness requested by the master).
 *
 * This file is autogenerated by make_gamma_table.py. Please edit there.
 */

const uint16_t gamma_table[4][256] = {"""

TABLE_START = \
"""
{
"""

TABLE_END = \
"""
},"""

FILE_END = \
"""
};
"""
if len(sys.argv) < 2:
    print("Error: Not enough arguments", file=sys.stderr)
    sys.exit(1)

bits = int(sys.argv[1])

gammas = []
for arg in range(2,len(sys.argv)):
    gammas.append(float(sys.argv[arg]))

tables = []

for g in gammas:
    table = []
    
    for i in range(256):
        table.append(min(((i/255) ** g) * (1 << bits), 0xffff))

    tables.append(table)

output = FILE_START

for table in tables:
    output += TABLE_START

    for i in range(256):
        t = table[i]
        output += "\t0x" + "{0:>04X}".format(round(t)) + ", // 0x" + "{0:>02X}".format(i) + "\n"

    output += TABLE_END

output += FILE_END

print(output)
