#ifndef USART_H
#define USART_H

#include <stdint.h>

#include "command.h"

/*
 * The type of filter function that can be passed to set_usart_filter.
 */
typedef uint8_t ((*usart_filter_t)(uint8_t));

/*
 * Initializes USART communication. This must be called before any other
 * function accessing the USART.
 * The mode argument determines, how the USARTs are configured:
 *
 * mode   | debug TX | command RX
 * -------+----------+-----------
 * NORMAL |  USART1  |  USART2
 * CONFIG |  USART1  |  USART1
 *
 * If anything goes wrong, the function immediately panics.
 */
mode_t usart_init();

/*
 * Returns a pointer to a buffer containing the next available USART command that
 * the current filter is interested in.
 * If no command is available, returns NULL.
 */
unsigned char *usart_next_command();

/*
 * Sets a command filter function for USART reception.
 * The filter gets passed a USART command and must return a nonzero value
 * to indicate interest in the command.
 */
void usart_set_filter(usart_filter_t filter);

#define debug_string(str) debug_write(STR_WITH_LEN(str))

/*
 * Sends a message via the "debug TX" USART.
 */
void debug_write(char *message, int length);

/*
 * Sends a character via the "debug TX" USART.
 */
void debug_putchar(char message);

/*
 * ISR for USART1.
 */
void isr_usart1();

/*
 * ISR for USART2.
 */
void isr_usart2();

#endif
